Languages class

Class responsible for storing information about module languages. Module will open in preferredLanguage. User will be able to change language to one of supportedLanguages.

Annotations
  • @JsonSerializable.new()

Constructors

Languages({required Language preferredLanguage, required List<Language> supportedLanguages})
Languages.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
preferredLanguage → Language
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportedLanguages → List<Language>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited