BlikAlias class

Class responsible for storing BLIK alias value and label that is displayed to the payer.

  • isRegistered - whether this alias was registered with a 6-digit code BLIK payment
Annotations
  • @JsonSerializable.new()

Constructors

BlikAlias({required bool isRegistered, required String value, required String label})
BlikAlias.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isRegistered → bool
final
label → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited