TokenizedCard class

Class responsible for storing credit card's token, cardTail and card brand.

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

TokenizedCard({required String token, required String cardTail, required CreditCardBrand brand})
TokenizedCard.fromJson(Map<String, dynamic> json)
factory

Properties

brand → CreditCardBrand
final
cardTail → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited