GooglePayOpenSuccess class

Indicates that payer has chosen credit card and data was received successfully

  • token - information about credit card from Google Pay response
  • description - credit card description, for example "Visa •••• 1111"
  • cardNetwork - credit card network
  • cardTail - last digits of credit card number
Inheritance

Constructors

GooglePayOpenSuccess({required String token, required String description, required String cardNetwork, required String cardTail})

Properties

cardNetwork → String
final
cardTail → String
final
description → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited