GooglePayUtilsConfiguration class

Class responsible for storing information about Google Pay utils configuration.

Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

GooglePayUtilsConfiguration({required double price, required String merchantName, required String merchantId, required GooglePayEnvironment environment, int? customRequestCode})
GooglePayUtilsConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

customRequestCode → int?
final
environment → GooglePayEnvironment
final
hashCode → int
The hash code for this object.
no setterinherited
merchantId → String
final
merchantName → String
final
price → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited