SingleTransaction class

Class responsible for storing information about standard Tpay UI module payment

Inheritance
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

SingleTransaction({required double amount, required String description, required PayerContext payerContext, String? hiddenDescription, Notifications? notifications})
SingleTransaction.fromJson(Map<String, dynamic> json)
factory

Properties

amount → double
finalinherited
description → String
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
hiddenDescription → String?
finalinherited
notifications → Notifications?
finalinherited
payerContext → PayerContext
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited