Transaction class

Class responsible for storing information about transaction amount and description.

Implementers
Annotations
  • @JsonSerializable.new(createToJson: false)

Constructors

Transaction({required double amount, required String description, String? hiddenDescription, Notifications? notifications})
Transaction.fromJson(Map<String, dynamic> json)
factory

Properties

amount → double
final
description → String
final
hashCode → int
The hash code for this object.
no setterinherited
hiddenDescription → String?
final
notifications → Notifications?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited